@@ -81,7 +81,7 @@ def test_localization_crud(host, token, project, video_type, video, box_type):
     video_obj = tator_api.get_media(video)
 
     # These fields will not be checked for object equivalence after patch.
-    exclude = ['project', 'type', 'media_id', 'id', 'meta', 'user']
+    exclude = ['project', 'type', 'media_id', 'id', 'meta', 'user', 'ids']
 
     # Test bulk create.
     num_localizations = random.randint(2000, 10000)
@@ -100,6 +100,20 @@ def test_localization_crud(host, token, project, video_type, video, box_type):
     response = tator_api.get_localization_list(project,type=box_type)
     assert len(response) == num_localizations
 
+    # Test media retrieval by localization ID.
+    response = tator_api.get_media_list_by_id(project, {'localization_ids': box_ids})
+    assert len(response) == 1
+    assert response[0].id == video
+    response = tator_api.get_media_list_by_id(project, {'localization_ids': box_ids}, force_es=1)
+    assert len(response) == 1
+    assert response[0].id == video
+
+    # Test box retrieval by media ID.
+    response = tator_api.get_localization_list_by_id(project, {'media_ids': [video]})
+    assert(len(response) == len(box_ids))
+    response = tator_api.get_localization_list_by_id(project, {'media_ids': [video]}, force_es=1)
+    assert(len(response) == len(box_ids))
+
     # Test single create.
     box = random_localization(project, box_type, video_obj, post=True)
     response = tator_api.create_localization_list(project, localization_spec=[box])
@@ -117,7 +131,9 @@ def test_localization_crud(host, token, project, video_type, video, box_type):
     assert_close_enough(patch, updated_box, exclude)
 
     # Get box by ID.
-    box_by_id = tator_api.get_localization_list_by_id(project, [box_id])[0]
+    box_by_id = tator_api.get_localization_list_by_id(project, {'ids': [box_id]})
+    assert(len(box_by_id) == 1)
+    box_by_id = box_by_id[0]
     assert_close_enough(updated_box, box_by_id, exclude)
 
     # Delete single box.
@@ -136,12 +152,24 @@ def test_localization_crud(host, token, project, video_type, video, box_type):
     assert isinstance(response, tator.models.MessageResponse)
     print(response.message)
 
+    # Bulk update specified boxes by ID.
+    id_bulk_patch = random_localization(project, box_type, video_obj)
+    update_ids = random.choices(box_ids, k=100)
+    id_bulk_patch = {'attributes': id_bulk_patch['attributes'], 'ids': update_ids}
+    response = tator_api.update_localization_list(project, **params,
+                                                  attribute_bulk_update=id_bulk_patch)
+    assert isinstance(response, tator.models.MessageResponse)
+    print(response.message)
+
     # Verify all boxes have been updated.
     boxes = tator_api.get_localization_list(project, **params)
     dataframe = tator.util.to_dataframe(boxes)
     assert(len(boxes)==len(dataframe))
     for box in boxes:
-        assert_close_enough(bulk_patch, box, exclude)
+        if box.id in update_ids:
+            assert_close_enough(id_bulk_patch, box, exclude)
+        else:
+            assert_close_enough(bulk_patch, box, exclude)
 
     # Do random queries using psql and elasticsearch and compare results.
     es_time = datetime.timedelta(seconds=0)
