@@ -73,7 +73,7 @@ def test_state_crud(host, token, project, video_type, video, state_type):
     video_obj = tator_api.get_media(video)
 
     # These fields will not be checked for object equivalence after patch.
-    exclude = ['project', 'type', 'media_ids', 'id', 'meta', 'user', 'frame']
+    exclude = ['project', 'type', 'media_ids', 'id', 'meta', 'user', 'frame', 'ids']
 
     # Test bulk create.
     num_states = random.randint(2000, 10000)
@@ -92,6 +92,20 @@ def test_state_crud(host, token, project, video_type, video, state_type):
     response = tator_api.get_state_list(project, type=state_type)
     assert len(response) == num_states
 
+    # Test media retrieval by state ID.
+    response = tator_api.get_media_list_by_id(project, {'state_ids': state_ids})
+    assert len(response) == 1
+    assert response[0].id == video
+    response = tator_api.get_media_list_by_id(project, {'state_ids': state_ids}, force_es=1)
+    assert len(response) == 1
+    assert response[0].id == video
+
+    # Test state retrival by media ID.
+    response = tator_api.get_state_list_by_id(project, {'media_ids': [video]})
+    assert(len(response) == len(state_ids))
+    response = tator_api.get_state_list_by_id(project, {'media_ids': [video]}, force_es=1)
+    assert(len(response) == len(state_ids))
+
     # Test single create.
     state = random_state(project, state_type, video_obj, post=True)
     response = tator_api.create_state_list(project, state_spec=[state])
@@ -99,8 +113,6 @@ def test_state_crud(host, token, project, video_type, video, state_type):
     print(response.message)
     state_id = response.id[0]
 
-
-
     # Patch single state.
     patch = random_state(project, state_type, video_obj)
     response = tator_api.update_state(state_id, state_update=patch)
@@ -113,7 +125,9 @@ def test_state_crud(host, token, project, video_type, video, state_type):
     assert_close_enough(patch, updated_state, exclude)
 
     # Get state by ID.
-    state_by_id = tator_api.get_state_list_by_id(project, [state_id])[0]
+    state_by_id = tator_api.get_state_list_by_id(project, {'ids': [state_id]})
+    assert(len(state_by_id) == 1)
+    state_by_id = state_by_id[0]
     assert_close_enough(updated_state, state_by_id, exclude)
 
     # Delete single state.
@@ -132,6 +146,25 @@ def test_state_crud(host, token, project, video_type, video, state_type):
     assert isinstance(response, tator.models.MessageResponse)
     print(response.message)
 
+    # Bulk update specified states by ID.
+    id_bulk_patch = random_state(project, state_type, video_obj)
+    update_ids = random.choices(state_ids, k=100)
+    id_bulk_patch = {'attributes': id_bulk_patch['attributes'], 'ids': update_ids}
+    response = tator_api.update_state_list(project, **params,
+                                           attribute_bulk_update=id_bulk_patch)
+    assert isinstance(response, tator.models.MessageResponse)
+    print(response.message)
+
+    # Verify all states have been updated.
+    states = tator_api.get_state_list(project, **params)
+    dataframe = tator.util.to_dataframe(states)
+    assert(len(states)==len(dataframe))
+    for state in states:
+        if state.id in update_ids:
+            assert_close_enough(id_bulk_patch, state, exclude)
+        else:
+            assert_close_enough(bulk_patch, state, exclude)
+
     # Do random queries using psql and elasticsearch and compare results.
     es_time = datetime.timedelta(seconds=0)
     psql_time = datetime.timedelta(seconds=0)
@@ -144,13 +177,6 @@ def test_state_crud(host, token, project, video_type, video, state_type):
     print(f"  Avg PSQL time: {psql_time / NUM_QUERIES}")
     print(f"  Avg ES time: {es_time / NUM_QUERIES}")
 
-    # Verify all states have been updated.
-    states = tator_api.get_state_list(project, **params)
-    dataframe = tator.util.to_dataframe(states)
-    assert(len(states)==len(dataframe))
-    for state in states:
-        assert_close_enough(bulk_patch, state, exclude)
-
     # Clone states to same media.
     version_mapping = {version.id: version.id for version in tator_api.get_version_list(project)}
     generator = tator.util.clone_state_list(tator_api, {**params, 'project': project},
